==> members-facade-2.4.1-20221010.073805-5-sources.jar: com/bizvane/members/facade/vo/qywx/MallShareStaffOrderListRequestVO.java <==
package com.bizvane.members.facade.vo.qywx;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Builder;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;

/**
 * @author baofeng@bizvane.cn
 * @createTime 2022-09-08 11:51:42
 * @description: 中台导购分享业绩-对账单分页列表查询请求对象
 */
@ApiModel(value = "中台导购分享业绩-对账单分页列表查询请求对象")
@Getter
@Setter
@Builder
public class MallShareStaffOrderListRequestVO {

    @NotNull(message = "企业ID不能为空")
    @ApiModelProperty(name = "sysCompanyId", value = "企业ID", required = true, example = "1L")
    private Long sysCompanyId;

    @NotNull(message = "品牌ID不能为空")
    @ApiModelProperty(name = "sysBrandId", value = "品牌ID", required = true, example = "1L")
    private Long sysBrandId;

    @NotBlank(message = "查询开始时间不能为空")
    @ApiModelProperty(name = "startDate", value = "查询开始时间", required = true, example = "")
    private String startDate;

    @NotBlank(message = "查询结束时间不能为空")
    @ApiModelProperty(name = "endDate", value = "查询结束时间", required = true, example = "")
    private String endDate;

    @NotBlank(message = "导购Code不能为空")
    @ApiModelProperty(name = "staffCode ", value = "导购Code", required = true, example = "")
    private String staffCode;

    @ApiModelProperty(name = "pageNo", value = "当前页数", required = false, example = "1")
    private Integer pageNo = 1;

    @ApiModelProperty(name = "pageSize", value = "显示条数", required = false, example = "10")
    private Integer pageSize = 10;

}

==> members-facade-2.5.7-20231011.173648-1-sources.jar: com/bizvane/members/facade/vo/qywx/MallShareStaffOrderListRequestVO.java <==
package com.bizvane.members.facade.vo.qywx;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Builder;
import lombok.Getter;
import lombok.Setter;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;

/**
 * @author baofeng@bizvane.cn
 * @createTime 2022-09-08 11:51:42
 * @description: 中台导购分享业绩-对账单分页列表查询请求对象
 */
@ApiModel(value = "中台导购分享业绩-对账单分页列表查询请求对象")
@Getter
@Setter
@Builder
public class MallShareStaffOrderListRequestVO {

    @NotNull(message = "企业ID不能为空")
    @ApiModelProperty(name = "sysCompanyId", value = "企业ID", required = true, example = "1L")
    private Long sysCompanyId;

    @NotNull(message = "品牌ID不能为空")
    @ApiModelProperty(name = "sysBrandId", value = "品牌ID", required = true, example = "1L")
    private Long sysBrandId;

    @NotBlank(message = "查询开始时间不能为空")
    @ApiModelProperty(name = "startDate", value = "查询开始时间", required = true, example = "")
    private String startDate;

    @NotBlank(message = "查询结束时间不能为空")
    @ApiModelProperty(name = "endDate", value = "查询结束时间", required = true, example = "")
    private String endDate;

    @NotBlank(message = "导购Code不能为空")
    @ApiModelProperty(name = "staffCode ", value = "导购Code", required = true, example = "")
    private String staffCode;

    @ApiModelProperty(name = "orderNo", value = "订单号", example = "")
    private String orderNo;

    @ApiModelProperty(name = "refundFlag", value = "退单标记 0：否 1：是", example = "")
    private Integer refundFlag;

    @ApiModelProperty(name = "pageNo", value = "当前页数", required = false, example = "1")
    private Integer pageNo = 1;

    @ApiModelProperty(name = "pageSize", value = "显示条数", required = false, example = "10")
    private Integer pageSize = 10;

}
